Reference
===============

Module functions
----------------

.. automodule:: leidenalg 
    :members: find_partition, 
              find_partition_multiplex, 
              find_partition_temporal,
              slices_to_layers,
              time_slices_to_layers,
    :undoc-members:
    :show-inheritance:

Optimiser 
---------

.. autoclass:: Optimiser
    :members:
    :undoc-members:
    :show-inheritance:

MutableVertexPartition
----------------------

.. autoclass:: leidenalg.VertexPartition.MutableVertexPartition
    :members:
    :undoc-members:
    :show-inheritance:

ModularityVertexPartition
-------------------------

.. autoclass:: ModularityVertexPartition
    :members:
    :undoc-members:
    :show-inheritance:

RBConfigurationVertexPartition
------------------------------

.. autoclass:: RBConfigurationVertexPartition 
    :members: resolution_parameter
    :undoc-members:
    :show-inheritance:

RBERVertexPartition
-------------------

.. autoclass:: RBERVertexPartition 
    :members:
    :undoc-members:
    :show-inheritance:

CPMVertexPartition
------------------

.. autoclass:: CPMVertexPartition
    :members:
    :undoc-members:
    :show-inheritance:

SignificanceVertexPartition
---------------------------

.. autoclass:: SignificanceVertexPartition
    :members:
    :undoc-members:
    :show-inheritance:

SurpriseVertexPartition
-----------------------

.. autoclass:: SurpriseVertexPartition
    :members:
    :undoc-members:
    :show-inheritance:

